import os
import json
import logging

logging.basicConfig(level=logging.INFO, format='%(levelname)s: %(message)s')

true = True
false = False
none = None

def rjson(file_or_CRU):
    try:
        with open(file_or_CRU, "r") as f:
            try:
                logging.info("Sucessfully read")
                return json.load(f)
            except json.JSONDecodeError:
                logging.error("Decodification error: Corrupted, incomplete or invalid JSON. Following...")
                return none
    except FileNotFoundError:
        try:
            logging.info("Sucessfully read")
            return json.loads(file_or_CRU)
        except json.JSONDecodeError:
            logging.error("Decodification error: Corrupted, incomplete or invalid JSON")
            return none
    except TypeError:
        logging.error("Invalid argument")
        return none
    except Exception as e:
        logging.error(f"Error: {e}")
        return none

def wjson(object, file=none):
    if file:
        try:
            with open(file, "w") as f:
                json.dump(object, f, indent=4)
            logging.info("Sucessfully written")
        except Exception as e:
            logging.error(f"Error: {e}")
        finally:
            return none
    else:
        try:
            return json.dumps(object)
        except TypeError as e:
            logging.error(f"Error: object is not JSON serializable: {e}")
            return none
        except Exception as e:
            logging.error(f"Error: {e}")



from setuptools import setup, find_packages

def readme() -> str:
    with open("README.md", "r", encoding = "utf-8") as f:
        return f.read()

setup(
    name = "golden-utils",
    version = "0.1.3",
    packages = find_packages(where = "src"),
    package_dir = {"": "src"},

    author = "Golden Dev",
    author_email = "miguizin.10@gmail.com",
    description = "Utilities for annoying or slowing details, like capitalizing booleans",
    long_description = readme(),
    long_description_content_type = "text/markdown; charset=UTF-8",
    url = "https://github.com/Goldencubist/golden-utils",
    license = "MIT",

    classifiers = [
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Operating System :: OS Independent",
        "Development Status :: 3 - Alpha",
        "License :: OSI Approved :: MIT License",
    ],
    python_requires = ">=3.8"
)